@@ -1,6 +1,6 @@
 "ordiarrows" <-
     function (ord, groups, levels, replicates, display = "sites", 
-              show.groups, ...) 
+              show.groups, startmark, ...) 
 {
     pts <- scores(ord, display = display, ...)
     npoints <- nrow(pts)
@@ -19,7 +19,12 @@
             X <- pts[gr, , drop = FALSE]
             X0 <- X[-nrow(X), , drop = FALSE]
             X1 <- X[-1, , drop = FALSE]
-            arrows(X0[, 1], X0[, 2], X1[, 1], X1[, 2], ...)
+            nseg <- nrow(X0)
+            if (!missing(startmark))
+                points(X0[1,1], X0[1,2], pch=startmark, ...)
+            if (nseg > 1) 
+                segments(X0[-nseg,1], X0[-nseg,2], X1[-nseg,1], X1[-nseg,2], ...)
+            arrows(X0[nseg, 1], X0[nseg, 2], X1[nseg, 1], X1[nseg, 2], ...)
         }
     }
     invisible()
