@@ -1,8 +1,10 @@
 "rda.formula" <-
-    function (formula, data, scale = FALSE) 
+function (formula, data, scale = FALSE, ...) 
 {
     if (missing(data)) {
         data <- parent.frame()
+    } else {
+        data <- ordiGetData(match.call(), environment(formula))
     }
     d <- ordiParseFormula(formula, data)
     sol <- rda.default(d$X, d$Y, d$Z, scale)
@@ -13,7 +15,7 @@
     if (!is.null(sol$CCA$centroids)) {
         rs <- rowSums(sol$CCA$centroids^2)
         sol$CCA$centroids <- sol$CCA$centroids[rs > 1e-04, , 
-                                               drop = FALSE]
+            drop = FALSE]
     }
     sol$terms <- d$terms
     sol$terminfo <- ordiTerminfo(d, data)
